| Title: | Interface to the web portal of Quantum Hydrometrie (https://wis.quantumhydro.de/wis/) |
|---|---|
| Description: | Functions to log in to the web portal of Quantum Hydrometrie, to export data and to log off. |
| Authors: | Hauke Sonnenberg |
| Maintainer: | Hauke Sonnenberg <[email protected]> |
| License: | GPL |
| Version: | 0.0.99 |
| Built: | 2026-05-16 09:29:36 UTC |
| Source: | https://github.com/KWB-R/kwb.quantum |